<?php
/**
 * Downloads setup page.
 *
 * @package productive-demo-importer
 */

function productive_demo_importer_register_section_1() {
    global $section_1_heading;
    add_settings_section(
        'productive_demo_importer_section_1',    // Section id
        $section_1_heading, // Section heading
        'productive_demo_importer_section_1_description_callback', // A callback method that displays the section description
        'productive_demo_importer_section_1_options'   // The menu slug of the page that will display this section
    );
    productive_demo_importer_add_section_1_fields('productive_demo_importer_section_1_options');
    // Register a new setting for "productive_demo_importer_section_1" section.
    register_setting( 
            'productive_demo_importer_section_1_options', // Option group (section)
            'productive_demo_importer_section_1_options',   // Option name (it holds a collection of values of associated field - e.g productive_demo_importer_section_1_options[field_name])
            'productive_demo_importer_register_section_1_validate'      // Validate user entry
        );
}
function productive_demo_importer_section_1_description_callback() {
    ?>
        <div class="warning-content bordered-left-info">
            <?php 
                echo esc_html( 'This demo importer plugin is designed for fresh installation of WordPress websites, as a starting guide. ', 'productive-demo-importer' );
                echo esc_html( 'Therefore, if this is a live website, you should not use this importer. ', 'productive-demo-importer' );
                echo esc_html( 'Instead, visit the documentation for the theme for a step by step set up set up guide.', 'productive-demo-importer' ); 
            ?>
        </div>
        <div>
            <?php 
                echo esc_html( 'If you are happy to proceed, select a theme and the desired demo content. Then start the import. ', 'productive-demo-importer' ); 
                echo esc_html( 'When the import completes, your website will have similar Menu, Widget settings and Customizer settings, similar to the demo site for the selected theme. ', 'productive-demo-importer' );
                echo esc_html( 'To import Demo Blog Posts and WooCommerce Products, please go to the "' . PRODUCTIVE_DEMO_IMPORTER_OPTION_TAB_2_TITLE . '" tab.', 'productive-demo-importer' );
            ?>
            <a target="_blank" href="<?php echo PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DOCUMENTATION_URL ?>"> 
                <?php echo esc_html( 'Check out the documentation', 'productive-demo-importer' )?></a>
            <?php echo esc_html( ' for help using this Demo Importer plugin.', 'productive-demo-importer' ); ?>
        </div>
<?php
}

/* ============ START Section fields ================= */
function productive_demo_importer_add_section_1_fields($productive_demo_importer_section_1_options) {

    // Add settings for Field 1 (section 1)
    $args_field_1 = array(                                  // Array of arguement that get passed to the call back (productive_demo_importer_callback_import_home_demo)
            'label_for'     => 'select_a_theme_box_id', 
            'class'  => 'options_field_args_css_class'
        );
    add_settings_field(
        'select_a_theme_box_id', // field id
        __( 'Select a Theme *', 'productive-demo-importer' ), // Field label
        'productive_demo_importer_callback_select_a_theme_box', // This callback function will be rendering this field. So, all html of this field will be rendered in this callback function.
        $productive_demo_importer_section_1_options,   // The menu slug of the page that will display this field
        'productive_demo_importer_section_1',   // Section name
        $args_field_1
        );
    // Add settings for Field 2 (section 1)
    $args_field_2 = array(                                  // Array of arguement that get passed to the call back (productive_demo_importer_callback_import_home_demo)
            'label_for'     => 'import_home_demo_id', 
            'class'  => 'options_field_args_css_class'
        );
    add_settings_field(
        'import_home_demo_id', // field id
        __( 'Import Homepage & Customisers?', 'productive-demo-importer' ), // Field label
        'productive_demo_importer_callback_import_home_demo', // This callback function will be rendering this field. So, all html of this field will be rendered in this callback function.
        $productive_demo_importer_section_1_options,   // The menu slug of the page that will display this field
        'productive_demo_importer_section_1',   // Section name
        $args_field_2
        );
    // Add settings for Field 3 (section 1)
    $args_field_3 = array(                                  // Array of arguement that get passed to the call back (productive_demo_importer_callback_import_home_demo)
            'label_for'     => 'import_menu_demo_id', 
            'class'  => 'options_field_args_css_class'
        );
    add_settings_field(
        'import_menu_demo_id', // field id
        __( 'Import Header & Footer Menu?', 'productive-demo-importer' ), // Field label
        'productive_demo_importer_callback_import_menu_demo', // This callback function will be rendering this field. So, all html of this field will be rendered in this callback function.
        $productive_demo_importer_section_1_options,   // The menu slug of the page that will display this field
        'productive_demo_importer_section_1',   // Section name
        $args_field_3
        );
    // Add settings for Field 4 (section 1)
    $args_field_4 = array(                                  // Array of arguement that get passed to the call back (productive_demo_importer_callback_import_home_demo)
            'label_for'     => 'read_notice_confirmation_id', 
            'class'  => 'options_field_args_css_class'
        );
    add_settings_field(
        'read_notice_confirmation_id', // field id
        __( 'Confirm this is a fresh WordPress website *', 'productive-demo-importer' ), // Field label
        'productive_demo_importer_callback_read_notice_confirmation', // This callback function will be rendering this field. So, all html of this field will be rendered in this callback function.
        $productive_demo_importer_section_1_options,   // The menu slug of the page that will display this field
        'productive_demo_importer_section_1',   // Section name
         $args_field_4
        );
}

// Callback function (Field 1, section 1)
function productive_demo_importer_callback_select_a_theme_box( $args ) {        
        // Get the Option name that we set for this field's section, using register_setting()
        $options = get_option( 'productive_demo_importer_section_1_options' );
    ?>
    <p>
        <select id="<?php echo esc_attr( $args['label_for'] ); ?>" class="<?php echo esc_attr( $args['class'] ); ?>"
                    name="productive_demo_importer_section_1_options[select_a_theme_box]">
            <option value="select_an_option" <?php echo selected( $options['select_a_theme_box'], 'select_an_option', false ); ?>>
                    <?php echo esc_html( 'Select a Theme', 'productive-demo-importer' ); ?>
            </option>
            <?php
            foreach ( Productive_Demo_Import_Global_Settings::get_all_themes() as $key => $theme_name ) {
            ?>
            <option value="<?php echo esc_attr($key) ?>" <?php echo selected( $options['select_a_theme_box'], 'ecommerce', false ); ?>>
                    <?php echo esc_attr($theme_name); ?>
                </option>
            <?php
            }
            ?>
        </select>
    </p>
    <?php
}

// Callback function (Field 2, section 1)
function productive_demo_importer_callback_import_home_demo( $args ) {
        $options = get_option( 'productive_demo_importer_section_1_options' );
    ?>
    <p>
        <input checked="checked" id="<?php echo esc_attr( $args['label_for'] ); ?>_yes" type="radio" name="productive_demo_importer_section_1_options[import_home_demo]" value="yes" <?php echo checked('yes', $options['import_home_demo'], false ); ?> />
        <label for="<?php echo esc_attr( $args['label_for'] ); ?>_yes"><?php echo esc_html( 'Yes', 'productive-demo-importer' ); ?></label>
        <input id="<?php echo esc_attr( $args['label_for'] ); ?>_no" type="radio" name="productive_demo_importer_section_1_options[import_home_demo]" value="no" <?php echo checked('no', $options['import_home_demo'], false ); ?> />
        <label for="<?php echo esc_attr( $args['label_for'] ); ?>_no"><?php echo esc_html( 'No', 'productive-demo-importer' ); ?></label>
    </p>
   <?php
}
// Callback function (Field 2, section 1)
function productive_demo_importer_callback_import_menu_demo( $args ) {
        $options = get_option( 'productive_demo_importer_section_1_options' );
    ?>
    <p>
        <input id="<?php echo esc_attr( $args['label_for'] ); ?>_yes" type="radio" name="productive_demo_importer_section_1_options[import_menu_demo]" value="yes" <?php echo checked('yes', $options['import_menu_demo'], false ); ?> />
        <label for="<?php echo esc_attr( $args['label_for'] ); ?>_yes"><?php echo esc_html( 'Yes', 'productive-demo-importer' ); ?></label>
        <input id="<?php echo esc_attr( $args['label_for'] ); ?>_no" type="radio" name="productive_demo_importer_section_1_options[import_menu_demo]" value="no" <?php echo checked('no', $options['import_menu_demo'], false ); ?> />
        <label for="<?php echo esc_attr( $args['label_for'] ); ?>_no"><?php echo esc_html( 'No', 'productive-demo-importer' ); ?></label>
    </p>
   <?php
}

// Callback function (Field 4, section 1)
function productive_demo_importer_callback_read_notice_confirmation( $args ) {
        $options = get_option( 'productive_demo_importer_section_1_options' );
    ?>
    <p>
        <input id="<?php echo esc_attr( $args['label_for'] ); ?>" class="<?php echo esc_attr( $args['class'] ); ?>"
               type="checkbox" name="productive_demo_importer_section_1_options[read_notice_confirmation]" value="ticked" <?php echo checked('ticked', $options['read_notice_confirmation'], false ); ?> />
        <label for="<?php echo esc_attr( $args['label_for'] ); ?>"><?php echo esc_html( 'Yes, this is a fresh WordPress Installation', 'productive-demo-importer' ); ?></label>
    </p>
   <?php
}
/* ============ END Section fields ================= */


function productive_demo_importer_register_section_1_validate( $section_inputs ) {
    $output = array();
    if ( !isset($section_inputs['read_notice_confirmation']) ) {
        add_settings_error( 'productive_demo_importer_section_1_options', 'productive_demo_importer_section_1_options[select_a_theme_box]', 'Please confirm you are using this tool for a fresh WordPress Installation' );
    } else {
        foreach ( $section_inputs as $key => $input ) {
            if ( isset($section_inputs[$key]) ) {
                if ( $key == 'select_a_theme_box' && $input == 'select_an_option' ) {
                    add_settings_error( 'productive_demo_importer_section_1_options', 'productive_demo_importer_section_1_options[select_a_theme_box]', 'Please select a theme to continue' );
                } else if ( $key == 'read_notice_confirmation' && $input != 'ticked' ) {
                    add_settings_error( 'productive_demo_importer_section_1_options', 'productive_demo_importer_section_1_options[select_a_theme_box]', $input );
                } else {
                    $output[$key] = strip_tags( stripslashes($input) );
                }
            }
        }    
    }
    return apply_filters('productive_demo_importer_register_section_1_validate', $output, $section_inputs);
}
