<?php
/**
 * Downloads setup page.
 *
 * @package productive-demo-importer
 */

if ( !defined('ABSPATH') ) {
	die();
}

$productive_demo_importer_admin_page_title = PRODUCTIVE_DEMO_IMPORTER_CURRENT_PLUGIN_NAME . esc_html__( ' Admin Page', 'productive-demo-importer' );
$productive_demo_importer_admin_submenu_title = PRODUCTIVE_DEMO_IMPORTER_CURRENT_PLUGIN_NAME;

/**
 * Render Pages and Menus
 * 
 * @global type $productive_demo_importer_admin_page_title
 * @global type $productive_demo_importer_admin_submenu_title
 */
function productive_demo_importer_plugin_options_render_page_menu() {
    
    global $productive_demo_importer_admin_page_title;
    global $productive_demo_importer_admin_submenu_title;
    
    $page_title         = $productive_demo_importer_admin_page_title;
    $menu_title         = $productive_demo_importer_admin_submenu_title;
    $capability         = 'administrator';          // allowed user role.
    $position           = 100; // Consider using later
    
    // Plugin Options SubMenu (under Appearance)
    // Register a new section in the "productive_demo_importer" page.
    add_plugins_page( 
        $page_title, 
        $menu_title, 
        $capability, 
        'productive_demo_importer_admin_options_path', 
        'productive_demo_importer_plugin_options_render_page_menu_html', 
        $position
    );
}
add_action( 'admin_menu', 'productive_demo_importer_plugin_options_render_page_menu' );

function productive_demo_importer_options_main_init() {
    // Register section 1
    productive_demo_importer_register_section_1();
    // Register section 2
    productive_demo_importer_register_section_2();
}
add_action( 'admin_init', 'productive_demo_importer_options_main_init' );

require PRODUCTIVE_DEMO_IMPORTER_PLUGIN_PATH . 'admin/options/partials/section-one.php';
require PRODUCTIVE_DEMO_IMPORTER_PLUGIN_PATH . 'admin/options/partials/section-two.php';

function productive_demo_importer_plugin_options_render_page_menu_html() {
    // check user capabilities
    if ( !current_user_can( 'manage_options' ) ) {
        add_settings_error( 'productive_demo_importer_admin_messages', 'productive_demo_importer_admin_message', esc_html__( 'You do not have permision to access this page', 'productive-demo-importer' ), 'error' );
        settings_errors( 'productive_demo_importer_admin_messages' );
    } else {
        
    global $productive_demo_importer_admin_page_title;
    
    // error/update messages
    settings_errors( 'productive_demo_importer_admin_messages' );
    ?>
    
	<?php 
	    $active_tab = 'section_1_options_tab';
		if( isset( $_GET[ 'tab' ] ) ) {
		    $active_tab = sanitize_text_field( $_GET[ 'tab' ] );
		}		
	?>
	
	<div class="wrap productive-demo-importer-options-page-wrapper">
            <div class="page-wrapper-heading">
                <h1>
                    <img style="vertical-align: middle; margin-right: 10px; border-radius: 5px;" src="<?php echo PRODUCTIVE_DEMO_IMPORTER_PLUGIN_URI . 'public/images/plugin-icon.png' ?>" alt="" width="60px" height="45px" />
                    <?php echo esc_attr($productive_demo_importer_admin_page_title); ?>
                </h1>
            </div>
            <div class="page-wrapper-body">
                
            <div class="page-wrapper-options-error">
                <?php settings_errors('productive_demo_importer_section_1_options'); ?>
                <?php settings_errors('productive_demo_importer_section_2_options'); ?>
            </div>

            <h2 class="nav-tab-wrapper">
                <a href="?page=productive_demo_importer_admin_options_path&tab=section_1_options_tab" class="nav-tab <?php echo $active_tab == 'section_1_options_tab' ? 'nav-tab-active' : ''; ?>"><?php echo PRODUCTIVE_DEMO_IMPORTER_OPTION_TAB_1_TITLE; ?></a>
                <a href="?page=productive_demo_importer_admin_options_path&tab=section_2_options_tab" class="nav-tab <?php echo $active_tab == 'section_2_options_tab' ? 'nav-tab-active' : ''; ?>"><?php echo PRODUCTIVE_DEMO_IMPORTER_OPTION_TAB_2_TITLE; ?></a>
            </h2>
                
            <form name="productive_demo_importer_options_form" method="post" action="options.php">
                <?php 
                    if ( $active_tab == 'section_1_options_tab' ) { ?>
                        <?php
                            settings_fields( 'productive_demo_importer_section_1_options' );
                            do_settings_sections( 'productive_demo_importer_section_1_options' );
                       ?>
                
                        <div class="warning-before-action-box"><?php echo esc_html( 'For best result, install and activate the selected theme before importing the demo content.', 'productive-demo-importer' ) ?></div>
                        <div id="info-is-loading-container-outer" class="info-is-loading-container-outer noned">
                                <div id="info-is-loading-container" class="info-is-loading-container">
                                <div class="demoimporter-content-overlay noned"><div class="transformer-container"><div class="transformer"></div></div></div>
                        <div id="is_loading_error_msg" class="noned"></div>
                        <div id="is_loading_success_msg" class="noned"></div>
                        <div id="is_loading_info_msg" class="noned"></div>
                        </div>
                        </div>
                       
                       <?php 
                            submit_button(esc_html( 'Start Import', 'productive-demo-importer' ), 'primary', 'demo_import_button');
                        ?>
                        
                    <?php } else if ( $active_tab == 'section_2_options_tab' ) { ?>
                        <?php
                            settings_fields( 'productive_demo_importer_section_2_options' );
                            do_settings_sections( 'productive_demo_importer_section_2_options' );
                        ?>
                    <?php } ?>
            </form>
        </div>
    </div>
    <?php
    }
}
