<?php
/**
 * Downloads setup page.
 *
 * @package productive-demo-importer
 */

if ( !defined('ABSPATH') ) {
	die();
}

/**
 * Plugin Name:       Productive Demo Importer
 * Plugin URI:        https://www.productiveminds.com/product/productive-demo-importer
 * Description:       The official demo content Importer for themes by productiveminds.com. This plugin will import demo content including Header and Footer menu, Widgets settings and customiser settings to set up your new WordPress website with similar content as our live demo of the theme. It is lightweight and works with little effort.
 * Version:           1.0.0
 * Requires at least: 5.2
 * Requires PHP:      5.3
 * Author:            productiveminds.com
 * Author URI:        https://www.productiveminds.com
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Update URI:        https://productiveminds.com/product/productive-demo-importer
 * Text Domain:       productive-demo-importer
 * Domain Path:       /languages
 */

if ( !defined('ABSPATH') ) {
    exit;
}

require_once plugin_dir_path( __FILE__ ) . 'global-settings.php';

if( ! function_exists('get_plugin_data') ){
    require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}
$productive_demo_importer_plugin_version_obj = get_plugin_data( __FILE__ );
$productive_demo_importer_plugin_version = $productive_demo_importer_plugin_version_obj['Version'];

$productiveminds_base_demo_url = 'https://demo.productiveminds.com';
$productiveminds_base_support_url = 'https://www.productiveminds.com/support';
$productiveminds_base_documentation_url = 'https://www.productiveminds.com/support/docs';

$plugin_name = $productive_demo_importer_plugin_version_obj[ 'Name' ];
$plugin_url = $productive_demo_importer_plugin_version_obj[ 'PluginURI' ];
$author_name = $productive_demo_importer_plugin_version_obj[ 'Author' ];
$author_url = $productive_demo_importer_plugin_version_obj[ 'AuthorURI' ];
$plugin_demo_url = $productiveminds_base_demo_url . '/' . $productive_demo_importer_plugin_version_obj[ 'TextDomain' ];
$plugin_support_url = $productiveminds_base_support_url;
$plugin_documentation_url = $productiveminds_base_documentation_url . '/' . $productive_demo_importer_plugin_version_obj[ 'TextDomain' ];
$plugin_wordpress_xml_import_documentation_url = $productiveminds_base_documentation_url . '/' . 'how-to-import-xml-data-with-wordpress-importer-plugin';
$plugin_download_from_repo_url = 'https://downloads.wordpress.org/plugin' . '/' . $productive_demo_importer_plugin_version_obj[ 'TextDomain' ] . 
        '.' . $productive_demo_importer_plugin_version . '.zip';

define( 'PRODUCTIVE_DEMO_IMPORTER_VERSION', $productive_demo_importer_plugin_version );
define( 'PRODUCTIVE_DEMO_IMPORTER_PRODUCT_DOWNLOAD_TYPE', 'product-download' );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DEVELOPER_NAME', 'productiveminds.com' );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DEVELOPER_WEBSITE', $author_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_CURRENT_PLUGIN_NAME', $plugin_name );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DEMO_URL', $plugin_demo_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_SUPPORT_URL', $plugin_support_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DOCUMENTATION_URL', $plugin_documentation_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_XML_IMPORT_DOCUMENTATION_URL', $plugin_wordpress_xml_import_documentation_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_DOWNLOAD_FROM_REPO_URL', $plugin_download_from_repo_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_FEATURES_OR_BUY_URL', $plugin_url );
define( 'PRODUCTIVE_DEMO_IMPORTER_PLUGIN_ICON', PRODUCTIVE_DEMO_IMPORTER_PLUGIN_URI . 'public/images/plugin-icon.webp' );

define( 'PRODUCTIVE_DEMO_IMPORTER_OPTION_TAB_1_TITLE', esc_html__( 'Import Theme Data', 'productive-demo-importer' ) );
define( 'PRODUCTIVE_DEMO_IMPORTER_OPTION_TAB_2_TITLE', esc_html__( 'Import Blogs and Products', 'productive-demo-importer' ) );


// These requires must be here, after global vars assignments
require_once PRODUCTIVE_DEMO_IMPORTER_PLUGIN_PATH . 'includes/activate.php';
require_once PRODUCTIVE_DEMO_IMPORTER_PLUGIN_PATH . 'includes/deactivate.php';
require_once PRODUCTIVE_DEMO_IMPORTER_PLUGIN_PATH . 'admin/options/settings.php';

// Start main plugin activation
register_activation_hook( __FILE__, 'productive_demo_importer_activate');

// Start main plugin deactivation
register_deactivation_hook( __FILE__, 'productive_demo_importer_deactivate' );

/**
 * Load (wp_enqueue_script) admin css * JS files.
 */
function productive_demo_importer_admin_scripts() {
    global $pagenow;
    if ( is_admin() && ( !empty( $pagenow ) && 'plugins.php' == $pagenow ) ) {
        
        global $productive_demo_importer_plugin_version;

        $admin_ajax_php_class = array(
            'ajax_admin_url' => admin_url( 'admin-ajax.php' ),
            'msg_error_select_a_theme' => esc_html( 'Select a Theme, then try again.', 'productive-demo-importer' ),
            'msg_error_confirm_fresh_install' => esc_html( 'Please confirm this is a fresh WordPress website, then try again.', 'productive-demo-importer' ),
            'msg_error_select_a_demo' => esc_html( 'Select the Required Demo Content (Homepage or Menu), then try again.', 'productive-demo-importer' ),
        );
        wp_enqueue_style( 'productive_demo_importer_admin_css', PRODUCTIVE_DEMO_IMPORTER_PLUGIN_URI . 'admin/css/admin-style.css', array(), $productive_demo_importer_plugin_version );
        wp_enqueue_script( 'productive_demo_importer_admin_js_handle', PRODUCTIVE_DEMO_IMPORTER_PLUGIN_URI . 'admin/js/admin-plugin.js', array(), $productive_demo_importer_plugin_version, true );

        wp_localize_script(
        'productive_demo_importer_admin_js_handle',
        'productive_demo_importer_admin_js_url_name',
        $admin_ajax_php_class
        );
    }
    
}
// hook for productive_demo_importer_admin_scripts.
add_action( 'admin_enqueue_scripts', 'productive_demo_importer_admin_scripts' );


	/**
	 * Method enable featured image.
	 */
function productive_demo_importer_setup_plugin() {
	// initiate text-domain.
	load_plugin_textdomain( 'productive-demo-importer', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
// hook for productive_demo_importer_setup_plugin.
add_action( 'init', 'productive_demo_importer_setup_plugin' );

